@@ -2,6 +2,7 @@
 
 import csv
 import datetime
+import math
 import os
 import re
 import shutil
@@ -15,6 +16,7 @@ import requests
 
 from .builder import Builder
 from .context import RuntimeContext
+from .cuda import cuda_check
 from .docker_id import docker_vm_id
 from .errors import WorkflowException
 from .job import ContainerCommandLineJob
@@ -156,8 +158,8 @@ class DockerCommandLineJob(ContainerCommandLineJob):
                 found = True
             elif "dockerFile" in docker_requirement:
                 dockerfile_dir = create_tmp_dir(tmp_outdir_prefix)
-                with open(os.path.join(dockerfile_dir, "Dockerfile"), "wb") as dfile:
-                    dfile.write(docker_requirement["dockerFile"].encode("utf-8"))
+                with open(os.path.join(dockerfile_dir, "Dockerfile"), "w") as dfile:
+                    dfile.write(docker_requirement["dockerFile"])
                 cmd = [
                     "docker",
                     "build",
@@ -395,6 +397,14 @@ class DockerCommandLineJob(ContainerCommandLineJob):
         if runtimeContext.rm_container:
             runtime.append("--rm")
 
+        cuda_req, _ = self.builder.get_requirement(
+            "http://commonwl.org/cwltool#CUDARequirement"
+        )
+        if cuda_req:
+            # Checked earlier that the device count is non-zero in _setup
+            count = cuda_check(cuda_req)
+            runtime.append("--gpus=" + str(count))
+
         cidfile_path = None  # type: Optional[str]
         # add parameters to docker to write a container ID file
         if runtimeContext.user_space_docker_cmd is None:
@@ -425,11 +435,12 @@ class DockerCommandLineJob(ContainerCommandLineJob):
         for key, value in self.environment.items():
             runtime.append(f"--env={key}={value}")
 
+        res_req, _ = self.builder.get_requirement("ResourceRequirement")
+
         if runtimeContext.strict_memory_limit and not user_space_docker_cmd:
             ram = self.builder.resources["ram"]
             runtime.append("--memory=%dm" % ram)
         elif not user_space_docker_cmd:
-            res_req, _ = self.builder.get_requirement("ResourceRequirement")
             if res_req and ("ramMin" in res_req or "ramMax" in res_req):
                 _logger.warning(
                     "[job %s] Skipping Docker software container '--memory' limit "
@@ -439,5 +450,18 @@ class DockerCommandLineJob(ContainerCommandLineJob):
                     "assurance.",
                     self.name,
                 )
+        if runtimeContext.strict_cpu_limit and not user_space_docker_cmd:
+            cpus = math.ceil(self.builder.resources["cores"])
+            runtime.append(f"--cpus={cpus}")
+        elif not user_space_docker_cmd:
+            if res_req and ("coresMin" in res_req or "coresMax" in res_req):
+                _logger.warning(
+                    "[job %s] Skipping Docker software container '--cpus' limit "
+                    "despite presence of ResourceRequirement with coresMin "
+                    "and/or coresMax setting. Consider running with "
+                    "--strict-cpu-limit for increased portability "
+                    "assurance.",
+                    self.name,
+                )
 
         return runtime, cidfile_path
