@@ -5,6 +5,7 @@ import logging
 import os
 import re
 import shutil
+import signal
 import stat
 import subprocess  # nosec
 import sys
@@ -41,6 +42,7 @@ from typing_extensions import TYPE_CHECKING
 from . import env_to_stdout, run_job
 from .builder import Builder
 from .context import RuntimeContext
+from .cuda import cuda_check
 from .errors import UnsupportedRequirement, WorkflowException
 from .loghandler import _logger
 from .pathmapper import MapperEnt, PathMapper
@@ -49,8 +51,8 @@ from .secrets import SecretStore
 from .utils import (
     CWLObjectType,
     CWLOutputType,
-    HasReqsHints,
     DirectoryType,
+    HasReqsHints,
     OutputCallbackType,
     bytes2str_in_dicts,
     create_tmp_dir,
@@ -173,6 +175,15 @@ class JobBase(HasReqsHints, metaclass=ABCMeta):
         pass
 
     def _setup(self, runtimeContext: RuntimeContext) -> None:
+
+        cuda_req, _ = self.builder.get_requirement(
+            "http://commonwl.org/cwltool#CUDARequirement"
+        )
+        if cuda_req:
+            count = cuda_check(cuda_req)
+            if count == 0:
+                raise WorkflowException("Could not satisfy CUDARequirement")
+
         if not os.path.exists(self.outdir):
             os.makedirs(self.outdir)
 
@@ -324,7 +335,7 @@ class JobBase(HasReqsHints, metaclass=ABCMeta):
                 )
 
             job_script_contents = None  # type: Optional[str]
-            builder = getattr(self, "builder", None)  # type: Builder
+            builder: Optional[Builder] = getattr(self, "builder", None)
             if builder is not None:
                 job_script_contents = builder.build_job_script(commands)
             rcode = _job_popen(
@@ -354,6 +365,16 @@ class JobBase(HasReqsHints, metaclass=ABCMeta):
             else:
                 processStatus = "permanentFail"
 
+            if processStatus != "success":
+                if rcode < 0:
+                    _logger.warning(
+                        "[job %s] was terminated by signal: %s",
+                        self.name,
+                        signal.Signals(-rcode).name,
+                    )
+                else:
+                    _logger.warning("[job %s] exited with status: %d", self.name, rcode)
+
             if "listing" in self.generatefiles:
                 if self.generatemapper:
                     relink_initialworkdir(
@@ -504,14 +525,17 @@ class JobBase(HasReqsHints, metaclass=ABCMeta):
 
         def get_tree_mem_usage(memory_usage: MutableSequence[Optional[int]]) -> None:
             children = monitor.children()
-            rss = monitor.memory_info().rss
-            while len(children):
-                rss += sum(process.memory_info().rss for process in children)
-                children = list(
-                    itertools.chain(*(process.children() for process in children))
-                )
-            if memory_usage[0] is None or rss > memory_usage[0]:
-                memory_usage[0] = rss
+            try:
+                rss = monitor.memory_info().rss
+                while len(children):
+                    rss += sum(process.memory_info().rss for process in children)
+                    children = list(
+                        itertools.chain(*(process.children() for process in children))
+                    )
+                if memory_usage[0] is None or rss > memory_usage[0]:
+                    memory_usage[0] = rss
+            except psutil.NoSuchProcess:
+                mem_tm.cancel()
 
         mem_tm = Timer(interval=1, function=get_tree_mem_usage, args=(memory_usage,))
         mem_tm.daemon = True
@@ -674,8 +698,8 @@ class ContainerCommandLineJob(JobBase, metaclass=ABCMeta):
         dirname = os.path.dirname(host_outdir_tgt or new_file)
         if not os.path.exists(dirname):
             os.makedirs(dirname)
-        with open(host_outdir_tgt or new_file, "wb") as file_literal:
-            file_literal.write(contents.encode("utf-8"))
+        with open(host_outdir_tgt or new_file, "w") as file_literal:
+            file_literal.write(contents)
         if not host_outdir_tgt:
             self.append_volume(runtime, new_file, volume.target, writable=writable)
         if writable:
@@ -876,7 +900,7 @@ class ContainerCommandLineJob(JobBase, metaclass=ABCMeta):
                     cid = cidhandle.readline().strip()
             except (OSError):
                 cid = None
-        max_mem = psutil.virtual_memory().total
+        max_mem = psutil.virtual_memory().total  # type: ignore[no-untyped-call]
         tmp_dir, tmp_prefix = os.path.split(tmpdir_prefix)
         stats_file = tempfile.NamedTemporaryFile(prefix=tmp_prefix, dir=tmp_dir)
         stats_file_name = stats_file.name
@@ -1020,8 +1044,8 @@ def _job_popen(
             ) as job_file:
                 json_dump(job_description, job_file, ensure_ascii=False)
             job_script = os.path.join(job_dir, "run_job.bash")
-            with open(job_script, "wb") as _:
-                _.write(job_script_contents.encode("utf-8"))
+            with open(job_script, "w") as _:
+                _.write(job_script_contents)
 
             job_run = os.path.join(job_dir, "run_job.py")
             shutil.copyfile(run_job.__file__, job_run)
@@ -1030,7 +1054,7 @@ def _job_popen(
             shutil.copyfile(env_to_stdout.__file__, env_getter)
 
             sproc = subprocess.Popen(  # nosec
-                ["bash", job_script.encode("utf-8")],
+                ["bash", job_script],
                 shell=False,  # nosec
                 cwd=job_dir,
                 # The nested script will output the paths to the correct files if they need
