@@ -434,6 +434,13 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
         else:
             runtime.extend(["--net", "--network", "none"])
 
+        cuda_req, _ = self.builder.get_requirement(
+            "http://commonwl.org/cwltool#CUDARequirement"
+        )
+        if cuda_req:
+            # Checked earlier that the device count is non-zero in _setup
+            runtime.append("--nv")
+
         for name, value in self.environment.items():
             env[f"SINGULARITYENV_{name}"] = str(value)
 
