@@ -101,14 +101,13 @@ JSONAtomType = Union[Dict[str, Any], List[Any], str, int, float, bool, None]
 JSONType = Union[
     Dict[str, JSONAtomType], List[JSONAtomType], str, int, float, bool, None
 ]
-WorkflowStateItem = NamedTuple(
-    "WorkflowStateItem",
-    [
-        ("parameter", CWLObjectType),
-        ("value", Optional[CWLOutputType]),
-        ("success", str),
-    ],
-)
+
+
+class WorkflowStateItem(NamedTuple):
+    parameter: CWLObjectType
+    value: Optional[CWLOutputType]
+    success: str
+
 
 ParametersType = List[CWLObjectType]
 StepType = CWLObjectType  # WorkflowStep
@@ -255,14 +254,14 @@ except ImportError:
 
 def shared_file_lock(fd: IO[Any]) -> None:
     if fcntl:
-        fcntl.flock(fd.fileno(), fcntl.LOCK_SH)  # type: ignore
+        fcntl.flock(fd.fileno(), fcntl.LOCK_SH)
     elif msvcrt:
-        msvcrt.locking(fd.fileno(), msvcrt.LK_LOCK, 1024)  # type: ignore
+        msvcrt.locking(fd.fileno(), msvcrt.LK_LOCK, 1024)
 
 
 def upgrade_lock(fd: IO[Any]) -> None:
     if fcntl:
-        fcntl.flock(fd.fileno(), fcntl.LOCK_EX)  # type: ignore
+        fcntl.flock(fd.fileno(), fcntl.LOCK_EX)
     elif msvcrt:
         pass
 
