@@ -1303,6 +1303,19 @@ def test_bad_stdout_expr_error() -> None:
     )
 
 
+@needs_docker
+def test_stdin_with_id_preset() -> None:
+    """Confirm that a type: stdin with a preset id does not give an error."""
+    error_code, _, stderr = get_main_output(
+        [
+            get_data("tests/wf/1590.cwl"),
+            "--file1",
+            get_data("tests/wf/whale.txt"),
+        ]
+    )
+    assert error_code == 0
+
+
 @needs_docker
 @pytest.mark.parametrize("factor", test_factors)
 def test_no_compute_chcksum(tmp_path: Path, factor: str) -> None:
@@ -1333,7 +1346,7 @@ def test_bad_userspace_runtime(factor: str) -> None:
     commands.extend(
         [
             "--user-space-docker-cmd=quaquioN",
-            "--default-container=debian",
+            "--default-container=docker.io/debian:stable-slim",
             get_data(test_file),
             get_data(job_file),
         ]
@@ -1360,7 +1373,14 @@ def test_bad_basecommand(factor: str) -> None:
 def test_bad_basecommand_docker(factor: str) -> None:
     test_file = "tests/wf/missing-tool.cwl"
     commands = factor.split()
-    commands.extend(["--debug", "--default-container", "debian", get_data(test_file)])
+    commands.extend(
+        [
+            "--debug",
+            "--default-container",
+            "docker.io/debian:stable-slim",
+            get_data(test_file),
+        ]
+    )
     error_code, stdout, stderr = get_main_output(commands)
     assert "permanentFail" in stderr, stderr
     assert error_code == 1
@@ -1574,3 +1594,27 @@ def test_custom_type_in_step_process() -> None:
         ]
     )
     assert err_code == 0
+
+
+def test_expression_tool_class() -> None:
+    """Confirm properties of the ExpressionTool class."""
+    factory = cwltool.factory.Factory()
+    tool_path = get_data("tests/wf/parseInt-tool.cwl")
+    expression_tool = factory.make(tool_path).t
+    assert str(expression_tool) == f"ExpressionTool: file://{tool_path}"
+
+
+def test_operation_class() -> None:
+    """Confirm properties of the AbstractOperation class."""
+    factory = cwltool.factory.Factory()
+    tool_path = get_data("tests/wf/operation/abstract-cosifer.cwl")
+    expression_tool = factory.make(tool_path).t
+    assert str(expression_tool) == f"AbstractOperation: file://{tool_path}"
+
+
+def test_command_line_tool_class() -> None:
+    """Confirm properties of the CommandLineTool class."""
+    factory = cwltool.factory.Factory()
+    tool_path = get_data("tests/echo.cwl")
+    expression_tool = factory.make(tool_path).t
+    assert str(expression_tool) == f"CommandLineTool: file://{tool_path}"
